/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA;
typedef struct tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ;
typedef struct tySequence__9chP3SzkaldXzawWQCDsqqg tySequence__9chP3SzkaldXzawWQCDsqqg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g tyTuple__aGv2fk9ceddvdC01ZJC2Q2g;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tySequence__vKogasEnJSPhbQmA8r4Y9aA tySequence__vKogasEnJSPhbQmA8r4Y9aA;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw;
typedef struct tySequence__ed0C0uAUZPhvw3RAc5hfYg tySequence__ed0C0uAUZPhvw3RAc5hfYg;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ;
typedef struct tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw;
typedef struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ;
typedef struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA tySequence__ZQPym9bf1jM5qaSn7LUXMKA;
typedef struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA;
typedef struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g;
typedef struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw;
typedef struct tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ;
typedef struct tySequence__FWZlrpY7KaSkhECxQricPA tySequence__FWZlrpY7KaSkhECxQricPA;
typedef struct tyObject_TIdNodePair__I349cp2jEFg44TpXYyniriw tyObject_TIdNodePair__I349cp2jEFg44TpXYyniriw;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef struct tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg;
typedef struct tySequence__q9cq1Li6c1nMjHpacEbCj0g tySequence__q9cq1Li6c1nMjHpacEbCj0g;
struct tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ {
tySequence__9chP3SzkaldXzawWQCDsqqg* data;
NI counter;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA {
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf;
tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ visited;
NIM_BOOL renderSymType;
NI indent;
NI currentLine;
NIM_BOOL firstItem;
NIM_BOOL useColor;
NimStringDesc* res;
};
struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g {
NI Field0;
void* Field1;
NI Field2;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU8 tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg;
typedef NU8 tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg;
typedef NU64 tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg kind;
tyEnum_TCallingConvention__5kpSva5OFmGFHujbio7C9cg callConv;
tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw flags;
tySequence__vKogasEnJSPhbQmA8r4Y9aA* sons;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typeInst;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg uniqueId;
};
typedef NU8 tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ {
  RootObj Sup;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* left;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* right;
NI L;
NimStringDesc* data;
};
typedef tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* tyArray__FKvM4FDhljtt88k8FkGthA[3];
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NU8 tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw {
NI counter;
tySequence__ed0C0uAUZPhvw3RAc5hfYg* data;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
struct tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw {
NI h;
};
struct tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
RootObj* val;
};
struct tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ {
NI counter;
tySequence__ZQPym9bf1jM5qaSn7LUXMKA* data;
};
struct tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g {
NI h;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
};
struct tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ {
NI counter;
tySequence__FWZlrpY7KaSkhECxQricPA* data;
};
struct tyObject_TIdNodePair__I349cp2jEFg44TpXYyniriw {
tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val;
};
typedef NU8 tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg;
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw {
NI elems;
NI counter;
NI max;
tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* head;
tySequence__q9cq1Li6c1nMjHpacEbCj0g* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tySequence__9chP3SzkaldXzawWQCDsqqg {
  TGenericSeq Sup;
  tyTuple__aGv2fk9ceddvdC01ZJC2Q2g data[SEQ_DECL_SIZE];
};
struct tySequence__ed0C0uAUZPhvw3RAc5hfYg {
  TGenericSeq Sup;
  tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* data[SEQ_DECL_SIZE];
};
struct tySequence__ZQPym9bf1jM5qaSn7LUXMKA {
  TGenericSeq Sup;
  tyObject_TIdPair__CEfaiHL4gHg86NKgeeQ7lA data[SEQ_DECL_SIZE];
};
struct tySequence__FWZlrpY7KaSkhECxQricPA {
  TGenericSeq Sup;
  tyObject_TIdNodePair__I349cp2jEFg44TpXYyniriw data[SEQ_DECL_SIZE];
};
struct tySequence__vKogasEnJSPhbQmA8r4Y9aA {
  TGenericSeq Sup;
  tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* data[SEQ_DECL_SIZE];
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
struct tySequence__q9cq1Li6c1nMjHpacEbCj0g {
  TGenericSeq Sup;
  tyObject_TrunkcolonObjectType___2fEZuM4UuXkgO9bDnaMLLWg* data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, debugSym)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTable__astalgo_3033)(NI initialSize, tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ* Result);
static N_NIMCALL(void, Marker_tySequence__9chP3SzkaldXzawWQCDsqqg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1103)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__astalgo_1178)(tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ t, void* key, NI default_0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___astalgo_1522)(tyObject_Table__pUwMsMsptf9bBz9chF6dJOrQ* t, void* key, NI val);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, openCurly__astalgo_1062)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, indentMore__astalgo_1039)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, key__astalgo_1072)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, newlineAndIndent__astalgo_1051)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2558)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1075)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1078)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, NI64 value);
static N_INLINE(NI, countBits64)(NU64 n);
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_61)(NU64 x);
N_CDECL(int, __builtin_popcountll)(unsigned long long x);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2578)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA value);
N_LIB_PRIVATE N_NIMCALL(void, openBracket__astalgo_1068)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2591)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA value);
N_LIB_PRIVATE N_NIMCALL(void, comma__astalgo_1066)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, closeBracket__astalgo_1070)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1097)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* value);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2734)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg value);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2754)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw value);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2767)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw value);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1100)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2933)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, comment__ast_997)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___ropes_250)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, lineInfoToStr__astalgo_28)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, percent___astalgo_353)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, makeYamlString__astalgo_330)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, add__ropes_159)(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ** a, tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_109)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toYamlChar__astalgo_320)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHex__pureZstrutils_1788)(NI x, NI len);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, rope__ropes_115)(NI64 i);
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
static N_INLINE(NI, toColumn__msgs_622)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2948)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg value);
static N_INLINE(NI, countBits32)(NU32 n);
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_26)(NU32 x);
N_CDECL(int, __builtin_popcount)(unsigned int x);
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2988)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg value);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toStrMaxPrecision__astalgo_920)(NF f);
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b);
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(void, closeCurly__astalgo_1064)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
N_LIB_PRIVATE N_NIMCALL(void, indentLess__astalgo_1045)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0);
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, debugType)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, debugNode)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
static N_INLINE(NI, nextTry__astalgo_90)(NI h, NI maxHash);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mustRehash__astalgo_87)(NI length, NI counter);
N_LIB_PRIVATE N_NIMCALL(void, strTableEnlarge__astalgo_3299)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, strTableRawInsert__astalgo_3245)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** data, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int495056_425)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ, getInt__ast_4593)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIter__astalgo_3755)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
N_LIB_PRIVATE N_NIMCALL(NI, idTableRawGet__astalgo_3806)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ t, NI key);
N_LIB_PRIVATE N_NIMCALL(void, idTableRawInsert__astalgo_3898)(tySequence__ZQPym9bf1jM5qaSn7LUXMKA** data, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, RootObj* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__astalgo_3401)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameIgnoreBacktickGensymInfo__astalgo_264)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentExcluding__astalgo_3425)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* excluding);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_3489)(tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupInRecord__astalgo_84)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, lastSon__ast_4833)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NI, idNodeTableRawGet__astalgo_4017)(tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key);
N_LIB_PRIVATE N_NIMCALL(void, idNodeTableRawInsert__astalgo_4064)(tySequence__FWZlrpY7KaSkhECxQricPA** data, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int495056_421)(tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ a, tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ b);
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValue__astalgo_135)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableInclReportConflict__astalgo_3335)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n, NIM_BOOL onConflictKeepOld);
N_LIB_PRIVATE N_NIMCALL(void, symTabReplaceRaw__astalgo_3270)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** data, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prevSym, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* newSym);
N_LIB_PRIVATE TNimType NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTIpointer__vr5DoT1jILTGdRlYv1OYpw_;
N_LIB_PRIVATE TNimType NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_3, "null", 4);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_4, "\033[90m", 5);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_5, "<defined ", 9);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_6, " lines upwards>", 15);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_7, "\033[0m", 4);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_8, "{", 1);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_9, ",", 1);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_10, "\012", 1);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_11, "\"", 1);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_12, "\": ", 3);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_13, "kind", 4);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_14, "\033[34m", 5);
extern TNimType NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_15, "name", 4);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_16, "\033[32m", 5);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_17, "id", 2);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_18, "\033[33m", 5);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_19, "position", 8);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_20, "flags", 5);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_21, "[", 1);
extern TNimType NTItsymflag__9be9c6fEXk5NwyPvxxb6toPA_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_22, ", ", 2);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_23, "]", 1);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_24, "typ", 3);
extern TNimType NTIttypekind__b28l2MkhJpnFhatVrsrXpg_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_25, "sym", 3);
extern TNimType NTIttypeflag__Vrztsndr9a9bj8bQ3cn49bwWw_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_26, "n", 1);
extern TNimType NTItnodekind__clSgDh22o9au33BrVH9bDQZw_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_27, "comment", 7);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_28, "info", 4);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_29, "\\u", 2);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_30, "command line", 12);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_31, "\?\?\?", 3);
extern TNimType NTItnodeflag__0RUKWdbLPY3l0smKVGDLMg_;
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_32, "nil", 3);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_33, "intVal", 6);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_34, "floatVal", 8);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_35, "strVal", 6);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_36, "ident", 5);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_37, "sons", 4);
STRING_LITERAL(TM__9cMUSicDjYZo0cQYwMNqa9cA_38, "}", 1);
extern TNimType NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_;
extern TNimType NTItidpairseq__ZQPym9bf1jM5qaSn7LUXMKA_;
extern TNimType NTItidnodepairseq__FWZlrpY7KaSkhECxQricPA_;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_NIMCALL(void, Marker_tySequence__9chP3SzkaldXzawWQCDsqqg)(void* p, NI op) {
	tySequence__9chP3SzkaldXzawWQCDsqqg* a;
	NI T1_;
	a = (tySequence__9chP3SzkaldXzawWQCDsqqg*)p;
	T1_ = (NI)0;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_189)(NimStringDesc** result, NI x) {
	addInt__stdZprivateZdigitsutils_167(result, ((NI64) (x)));
}
N_LIB_PRIVATE N_NIMCALL(void, indentMore__astalgo_1039)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	(*this_0).indent += ((NI) 2);
}
N_LIB_PRIVATE N_NIMCALL(void, openCurly__astalgo_1062)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_8));
	indentMore__astalgo_1039(this_0);
	(*this_0).firstItem = NIM_TRUE;
}
N_LIB_PRIVATE N_NIMCALL(void, newlineAndIndent__astalgo_1051)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_10));
	(*this_0).currentLine += ((NI) 1);
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < (*this_0).indent)) goto LA3;
				i = i_2;
				unsureAsgnRef((void**) (&(*this_0).res), addChar((*this_0).res, 32));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, key__astalgo_1072)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, NimStringDesc* key) {
	{
		if (!!((*this_0).firstItem)) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_9));
	}
	LA3_: ;
	(*this_0).firstItem = NIM_FALSE;
	newlineAndIndent__astalgo_1051(this_0);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (key ? key->Sup.len : 0) + 0));
appendString((*this_0).res, key);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 3));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_12));
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2558)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_14));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)) ? reprEnum((NI)value, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTItsymkind__sjiB9b9aO1FRPetW6gPYZbfw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1075)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, NimStringDesc* value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_16));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (value ? value->Sup.len : 0) + 0));
appendString((*this_0).res, value);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1078)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, NI64 value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_18));
	}
	LA3_: ;
	addInt__stdZprivateZdigitsutils_167((&(*this_0).res), value);
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_61)(NU64 x) {
	NI result;
	int T1_;
	result = (NI)0;
	T1_ = (int)0;
	T1_ = __builtin_popcountll(x);
	result = ((NI) (T1_));
	return result;
}
static N_INLINE(NI, countBits64)(NU64 n) {
	NI result;
	result = (NI)0;
	result = countSetBitsImpl__systemZcountbits95impl_61(n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, openBracket__astalgo_1068)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_21));
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2591)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_14));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTItsymflag__9be9c6fEXk5NwyPvxxb6toPA_)) ? reprEnum((NI)value, (&NTItsymflag__9be9c6fEXk5NwyPvxxb6toPA_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTItsymflag__9be9c6fEXk5NwyPvxxb6toPA_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, comma__astalgo_1066)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 2));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_22));
}
N_LIB_PRIVATE N_NIMCALL(void, closeBracket__astalgo_1070)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_23));
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2578)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA value) {
	NI high;
	NI i;
	openBracket__astalgo_1068(this_0);
	high = (NI)(countBits64(value) - ((NI) 1));
	i = ((NI) 0);
	{
		tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA v;
		NI i_2;
		v = (tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 <= ((NI) 48))) goto LA3;
				{
					if (!((value &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) (i_2)))&63U)))!=0)) goto LA6_;
					v = ((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) (i_2));
					value__astalgo_2591(this_0, v);
					{
						if (!!((i == high))) goto LA10_;
						comma__astalgo_1066(this_0);
					}
					LA10_: ;
					i += ((NI) 1);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	closeBracket__astalgo_1070(this_0);
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2734)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_14));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)) ? reprEnum((NI)value, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTIttypekind__b28l2MkhJpnFhatVrsrXpg_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2767)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_14));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTIttypeflag__Vrztsndr9a9bj8bQ3cn49bwWw_)) ? reprEnum((NI)value, (&NTIttypeflag__Vrztsndr9a9bj8bQ3cn49bwWw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTIttypeflag__Vrztsndr9a9bj8bQ3cn49bwWw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2754)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tySet_tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw value) {
	NI high;
	NI i;
	openBracket__astalgo_1068(this_0);
	high = (NI)(countBits64(value) - ((NI) 1));
	i = ((NI) 0);
	{
		tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw v;
		NI i_2;
		v = (tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 <= ((NI) 44))) goto LA3;
				{
					if (!((value &((NU64)1<<((NU)(((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) (i_2)))&63U)))!=0)) goto LA6_;
					v = ((tyEnum_TTypeFlag__Vrztsndr9a9bj8bQ3cn49bwWw) (i_2));
					value__astalgo_2767(this_0, v);
					{
						if (!!((i == high))) goto LA10_;
						comma__astalgo_1066(this_0);
					}
					LA10_: ;
					i += ((NI) 1);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	closeBracket__astalgo_1070(this_0);
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2933)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_14));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)) ? reprEnum((NI)value, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTItnodekind__clSgDh22o9au33BrVH9bDQZw_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toYamlChar__astalgo_320)(NIM_CHAR c) {
	NimStringDesc* result;
	result = NIM_NIL;
	switch (((NU8)(c))) {
	case 0 ... 31:
	case 127 ... 255:
	{
		NimStringDesc* T2_;
		NimStringDesc* T3_;
		T2_ = NIM_NIL;
		T3_ = NIM_NIL;
		T3_ = toHex__pureZstrutils_1788(((NU8)(c)), ((NI) 4));
		T2_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 2);
appendString(T2_, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_29));
appendString(T2_, T3_);
		result = T2_;
	}
	break;
	case 39:
	case 34:
	case 92:
	{
		NimStringDesc* T5_;
		T5_ = NIM_NIL;
		T5_ = rawNewString(2);
appendChar(T5_, 92);
appendChar(T5_, c);
		result = T5_;
	}
	break;
	default:
	{
		result = nimCharToStr(c);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, makeYamlString__astalgo_330)(NimStringDesc* s) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	NimStringDesc* res;
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T10_;
	result = NIM_NIL;
	result = ((tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*) NIM_NIL);
	res = copyString(((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (s ? s->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				NimStringDesc* T9_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T8_;
					if (!((NI)((NI)(i + ((NI) 1)) % ((NI) 64)) == ((NI) 0))) goto LA6_;
					res = addChar(res, 34);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_10));
					T8_ = NIM_NIL;
					T8_ = rope__ropes_109(res);
					add__ropes_159(&result, T8_);
					res = copyString(((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
				}
				LA6_: ;
				T9_ = NIM_NIL;
				T9_ = toYamlChar__astalgo_320(s->data[i]);
				res = resizeString(res, (T9_ ? T9_->Sup.len : 0) + 0);
appendString(res, T9_);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	res = addChar(res, 34);
	T10_ = NIM_NIL;
	T10_ = rope__ropes_109(res);
	add__ropes_159(&result, T10_);
	return result;
}
static N_INLINE(NI, toLinenumber__msgs_619)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__msgs_622)(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ*, lineInfoToStr__astalgo_28)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info) {
	tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* result;
	tyArray__FKvM4FDhljtt88k8FkGthA T1_;
	NimStringDesc* T2_;
	NI T15_;
	NI T16_;
	result = NIM_NIL;
	nimZeroMem((void*)T1_, sizeof(tyArray__FKvM4FDhljtt88k8FkGthA));
	T2_ = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (info.fileIndex < ((NI32) 0));
		if (T5_) goto LA6_;
		T5_ = (conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL));
		LA6_: ;
		if (!T5_) goto LA7_;
		{
			if (!(info.fileIndex == ((NI32) -3))) goto LA11_;
			T2_ = copyString(((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_30));
		}
		goto LA9_;
		LA11_: ;
		{
			T2_ = copyString(((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_31));
		}
		LA9_: ;
	}
	goto LA3_;
	LA7_: ;
	{
		T2_ = copyString((*conf).m.fileInfos->data[info.fileIndex].shortName);
	}
	LA3_: ;
	T1_[0] = makeYamlString__astalgo_330(T2_);
	T15_ = (NI)0;
	T15_ = toLinenumber__msgs_619(info);
	T1_[1] = rope__ropes_115(((NI64) (T15_)));
	T16_ = (NI)0;
	T16_ = toColumn__msgs_622(info);
	T1_[2] = rope__ropes_115(((NI64) (T16_)));
	result = percent___astalgo_353(T1_, 3);
	return result;
}
static N_INLINE(NI, countSetBitsImpl__systemZcountbits95impl_26)(NU32 x) {
	NI result;
	int T1_;
	result = (NI)0;
	T1_ = (int)0;
	T1_ = __builtin_popcount(x);
	result = ((NI) (T1_));
	return result;
}
static N_INLINE(NI, countBits32)(NU32 n) {
	NI result;
	result = (NI)0;
	result = countSetBitsImpl__systemZcountbits95impl_26(n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2988)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg value) {
	{
		if (!(*this_0).useColor) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_14));
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, (reprEnum((NI)value, (&NTItnodeflag__0RUKWdbLPY3l0smKVGDLMg_)) ? reprEnum((NI)value, (&NTItnodeflag__0RUKWdbLPY3l0smKVGDLMg_))->Sup.len : 0) + 0));
appendString((*this_0).res, reprEnum((NI)value, (&NTItnodeflag__0RUKWdbLPY3l0smKVGDLMg_)));
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_11));
	{
		if (!(*this_0).useColor) goto LA7_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_2948)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg value) {
	NI high;
	NI i;
	openBracket__astalgo_1068(this_0);
	high = (NI)(countBits32(value) - ((NI) 1));
	i = ((NI) 0);
	{
		tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg v;
		NI i_2;
		v = (tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 <= ((NI) 24))) goto LA3;
				{
					if (!((value &((NU32)1<<((NU)(((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) (i_2)))&31U)))!=0)) goto LA6_;
					v = ((tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg) (i_2));
					value__astalgo_2988(this_0, v);
					{
						if (!!((i == high))) goto LA10_;
						comma__astalgo_1066(this_0);
					}
					LA10_: ;
					i += ((NI) 1);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	closeBracket__astalgo_1070(this_0);
}
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a == 0);
		if (T3_) goto LA4_;
		T3_ = (b == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (a == b);
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((*a).id == (*b).id);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__ast_3155)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, indentLess__astalgo_1045)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	(*this_0).indent -= ((NI) 2);
}
N_LIB_PRIVATE N_NIMCALL(void, closeCurly__astalgo_1064)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0) {
	indentLess__astalgo_1045(this_0);
	newlineAndIndent__astalgo_1051(this_0);
	unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 1));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_38));
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1100)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* value) {
	NI indexX60gensym127_;
{	{
		if (!(value == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_3));
		goto BeforeRet_;
	}
	LA3_: ;
	indexX60gensym127_ = getOrDefault__astalgo_1178((*this_0).visited, ((void*) (value)), ((NI) -1));
	{
		if (!(indexX60gensym127_ < ((NI) 0))) goto LA7_;
		X5BX5Deq___astalgo_1522((&(*this_0).visited), ((void*) (value)), (*this_0).currentLine);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!(*this_0).useColor) goto LA12_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_4));
		}
		LA12_: ;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 9));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_5));
		addInt__stdZprivateZdigitsutils_189((&(*this_0).res), (NI)((*this_0).currentLine - indexX60gensym127_));
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 15));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_6));
		{
			if (!(*this_0).useColor) goto LA16_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
		}
		LA16_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	openCurly__astalgo_1062(this_0);
	key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_13));
	value__astalgo_2933(this_0, (*value).kind);
	{
		NimStringDesc* T20_;
		NimStringDesc* T23_;
		T20_ = NIM_NIL;
		T20_ = comment__ast_997(value);
		if (!(((NI) 0) < (T20_ ? T20_->Sup.len : 0))) goto LA21_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_27));
		T23_ = NIM_NIL;
		T23_ = comment__ast_997(value);
		value__astalgo_1075(this_0, T23_);
	}
	LA21_: ;
	{
		tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* T28_;
		NimStringDesc* T29_;
		if (!!(((*this_0).conf == ((tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ*) NIM_NIL)))) goto LA26_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_28));
		T28_ = NIM_NIL;
		T28_ = lineInfoToStr__astalgo_28((*this_0).conf, (*value).info);
		T29_ = NIM_NIL;
		T29_ = dollar___ropes_250(T28_);
		value__astalgo_1075(this_0, T29_);
	}
	LA26_: ;
	{
		if (!!(((*value).flags == 0))) goto LA32_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_20));
		value__astalgo_2948(this_0, (*value).flags);
	}
	LA32_: ;
	{
		if (!!(((*value).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)))) goto LA36_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_24));
		value__astalgo_2734(this_0, (*(*value).typ).kind);
	}
	goto LA34_;
	LA36_: ;
	{
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_24));
		value__astalgo_1075(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_32));
	}
	LA34_: ;
	switch ((*value).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_33));
		value__astalgo_1078(this_0, (*value)._kind_1.intVal);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 17):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
	{
		NimStringDesc* T41_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_34));
		T41_ = NIM_NIL;
		T41_ = toStrMaxPrecision__astalgo_920((*value)._kind_2.floatVal);
		value__astalgo_1075(this_0, T41_);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_35));
		value__astalgo_1075(this_0, (*value)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_25));
		value__astalgo_1103(this_0, (*value)._kind_4.sym);
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2):
	{
		{
			NIM_BOOL T47_;
			T47_ = (NIM_BOOL)0;
			T47_ = eqeq___idents_229((*value)._kind_5.ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
			if (!!(T47_)) goto LA48_;
			key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_36));
			value__astalgo_1075(this_0, (*(*value)._kind_5.ident).s);
		}
		LA48_: ;
	}
	break;
	default:
	{
		{
			NIM_BOOL T53_;
			T53_ = (NIM_BOOL)0;
			T53_ = (*this_0).renderSymType;
			if (!(T53_)) goto LA54_;
			T53_ = !(((*value).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
			LA54_: ;
			if (!T53_) goto LA55_;
			key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_24));
			value__astalgo_1097(this_0, (*value).typ);
		}
		LA55_: ;
		{
			NI T59_;
			T59_ = (NI)0;
			T59_ = len__ast_3155(value);
			if (!(((NI) 0) < T59_)) goto LA60_;
			key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_37));
			openBracket__astalgo_1068(this_0);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_3155(value);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA64;
						i = i_2;
						value__astalgo_1100(this_0, (*value)._kind_6.sons->data[i]);
						{
							NI T67_;
							T67_ = (NI)0;
							T67_ = len__ast_3155(value);
							if (!!((i == (NI)(T67_ - ((NI) 1))))) goto LA68_;
							comma__astalgo_1066(this_0);
						}
						LA68_: ;
						i_2 += ((NI) 1);
					} LA64: ;
				}
			}
			closeBracket__astalgo_1070(this_0);
		}
		LA60_: ;
	}
	break;
	}
	closeCurly__astalgo_1064(this_0);
	}BeforeRet_: ;
}
static N_INLINE(NI, len__ast_3990)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1097)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* value) {
	NI indexX60gensym117_;
	tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* xX60gensym118_;
{	{
		if (!(value == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_3));
		goto BeforeRet_;
	}
	LA3_: ;
	indexX60gensym117_ = getOrDefault__astalgo_1178((*this_0).visited, ((void*) (value)), ((NI) -1));
	{
		if (!(indexX60gensym117_ < ((NI) 0))) goto LA7_;
		X5BX5Deq___astalgo_1522((&(*this_0).visited), ((void*) (value)), (*this_0).currentLine);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!(*this_0).useColor) goto LA12_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_4));
		}
		LA12_: ;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 9));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_5));
		addInt__stdZprivateZdigitsutils_189((&(*this_0).res), (NI)((*this_0).currentLine - indexX60gensym117_));
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 15));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_6));
		{
			if (!(*this_0).useColor) goto LA16_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
		}
		LA16_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	openCurly__astalgo_1062(this_0);
	key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_13));
	value__astalgo_2734(this_0, (*value).kind);
	key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_17));
	xX60gensym118_ = value;
	value__astalgo_1078(this_0, ((NI64) ((NI)((NI)((NU64)(((NI) ((*xX60gensym118_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym118_).Sup.itemId.item))))));
	{
		if (!!(((*value).sym == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA20_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_25));
		value__astalgo_1103(this_0, (*value).sym);
	}
	LA20_: ;
	{
		if (!(((NI) 0) < countBits64((*value).flags))) goto LA24_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_20));
		value__astalgo_2754(this_0, (*value).flags);
	}
	LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = ((*value).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 1) || (*value).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 2) || (*value).kind == ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 14) || (*value).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 31) && (*value).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 35) || (*value).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 36) && (*value).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 39) || (*value).kind >= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 40) && (*value).kind <= ((tyEnum_TTypeKind__b28l2MkhJpnFhatVrsrXpg) 44));
		if (!(T28_)) goto LA29_;
		T28_ = !(((*value).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)));
		LA29_: ;
		if (!T28_) goto LA30_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_26));
		value__astalgo_1100(this_0, (*value).n);
	}
	LA30_: ;
	{
		NI T34_;
		T34_ = (NI)0;
		T34_ = len__ast_3990(value);
		if (!(((NI) 0) < T34_)) goto LA35_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_37));
		openBracket__astalgo_1068(this_0);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3990(value);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA39;
					i = i_2;
					value__astalgo_1097(this_0, (*value).sons->data[i]);
					{
						NI T42_;
						T42_ = (NI)0;
						T42_ = len__ast_3990(value);
						if (!!((i == (NI)(T42_ - ((NI) 1))))) goto LA43_;
						comma__astalgo_1066(this_0);
					}
					LA43_: ;
					i_2 += ((NI) 1);
				} LA39: ;
			}
		}
		closeBracket__astalgo_1070(this_0);
	}
	LA35_: ;
	{
		if (!!(((*value).n == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA47_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_26));
		value__astalgo_1100(this_0, (*value).n);
	}
	LA47_: ;
	closeCurly__astalgo_1064(this_0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, value__astalgo_1103)(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA* this_0, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* value) {
	NI indexX60gensym96_;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym113_;
{	{
		if (!(value == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA3_;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_3));
		goto BeforeRet_;
	}
	LA3_: ;
	indexX60gensym96_ = getOrDefault__astalgo_1178((*this_0).visited, ((void*) (value)), ((NI) -1));
	{
		if (!(indexX60gensym96_ < ((NI) 0))) goto LA7_;
		X5BX5Deq___astalgo_1522((&(*this_0).visited), ((void*) (value)), (*this_0).currentLine);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			if (!(*this_0).useColor) goto LA12_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 5));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_4));
		}
		LA12_: ;
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 9));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_5));
		addInt__stdZprivateZdigitsutils_189((&(*this_0).res), (NI)((*this_0).currentLine - indexX60gensym96_));
		unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 15));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_6));
		{
			if (!(*this_0).useColor) goto LA16_;
			unsureAsgnRef((void**) (&(*this_0).res), resizeString((*this_0).res, 4));
appendString((*this_0).res, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_7));
		}
		LA16_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	openCurly__astalgo_1062(this_0);
	key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_13));
	value__astalgo_2558(this_0, (*value).kind);
	key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_15));
	value__astalgo_1075(this_0, (*(*value).name).s);
	key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_17));
	xX60gensym113_ = value;
	value__astalgo_1078(this_0, ((NI64) ((NI)((NI)((NU64)(((NI) ((*xX60gensym113_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym113_).Sup.itemId.item))))));
	{
		if (!((1572872 &((NU32)1<<((NU)((*value).kind)&31U)))!=0)) goto LA20_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_19));
		value__astalgo_1078(this_0, ((NI64) ((*value).position)));
	}
	LA20_: ;
	{
		if (!(((NI) 0) < countBits64((*value).flags))) goto LA24_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_20));
		value__astalgo_2578(this_0, (*value).flags);
	}
	LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = (*this_0).renderSymType;
		if (!(T28_)) goto LA29_;
		T28_ = !(((*value).typ == ((tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA*) NIM_NIL)));
		LA29_: ;
		if (!T28_) goto LA30_;
		key__astalgo_1072(this_0, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_24));
		value__astalgo_1097(this_0, (*value).typ);
	}
	LA30_: ;
	closeCurly__astalgo_1064(this_0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, debugSym)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA this_1;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&this_1), sizeof(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA));
	initTable__astalgo_3033(((NI) 32), (&this_1.visited));
	this_1.renderSymType = NIM_TRUE;
	this_1.useColor = NIM_TRUE;
	value__astalgo_1103((&this_1), n);
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString(this_1.res);
	echoBinSafe(T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(void, debugType)(tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA this_1;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&this_1), sizeof(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA));
	initTable__astalgo_3033(((NI) 32), (&this_1.visited));
	this_1.renderSymType = NIM_TRUE;
	this_1.useColor = NIM_TRUE;
	value__astalgo_1097((&this_1), n);
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString(this_1.res);
	echoBinSafe(T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(void, debugNode)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf) {
	tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA this_1;
	tyArray__nHXaesL0DJZHyVS07ARPRA T1_;
	nimZeroMem((void*)(&this_1), sizeof(tyObject_DebugPrinter__fb29bTXwka5DC6l2X4zP3SA));
	initTable__astalgo_3033(((NI) 32), (&this_1.visited));
	this_1.useColor = NIM_TRUE;
	value__astalgo_1100((&this_1), n);
	nimZeroMem((void*)T1_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T1_[0] = copyString(this_1.res);
	echoBinSafe(T1_, 1);
}
static N_INLINE(NI, nextTry__astalgo_90)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)((NI)(((NI) 5) * h) + ((NI) 1)) & maxHash);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableGet__astalgo_3383)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw t, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI h;
	NI T1_;
	result = NIM_NIL;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*name).h & T1_);
	{
		while (1) {
			NI T12_;
			result = t.data->data[h];
			{
				if (!(result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			{
				if (!((*(*result).name).id == (*name).id)) goto LA10_;
				goto LA2;
			}
			LA10_: ;
			T12_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T12_);
		}
	} LA2: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mustRehash__astalgo_87)(NI length, NI counter) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((NI)(length * ((NI) 2)) < (NI)(counter * ((NI) 3)));
	if (T1_) goto LA2_;
	T1_ = ((NI)(length - counter) < ((NI) 4));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableRawInsert__astalgo_3245)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** data, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n) {
	NI h;
	NI T1_;
{	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((*(*n).name).h & T1_);
	{
		while (1) {
			NI T8_;
			if (!!(((*data)->data[h] == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3;
			{
				if (!((*data)->data[h] == n)) goto LA6_;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T8_);
		} LA3: ;
	}
	asgnRef((void**) (&(*data)->data[h]), n);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableEnlarge__astalgo_3299)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t) {
	tySequence__ed0C0uAUZPhvw3RAc5hfYg* n;
	NI T1_;
	tySequence__ed0C0uAUZPhvw3RAc5hfYg* T10_;
	n = NIM_NIL;
	T1_ = ((*t).data ? (*t).data->Sup.len : 0);
	n = (tySequence__ed0C0uAUZPhvw3RAc5hfYg*) newSeq((&NTIseqLpsymT__ed0C0uAUZPhvw3RAc5hfYg_), ((NI) ((NI)(T1_ * ((NI) 2)))));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA5;
				i = res;
				{
					if (!!(((*t).data->data[i] == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA8_;
					strTableRawInsert__astalgo_3245((&n), (*t).data->data[i]);
				}
				LA8_: ;
				res += ((NI) 1);
			} LA5: ;
		}
	}
	T10_ = NIM_NIL;
	T10_ = (*t).data;
	unsureAsgnRef((void**) (&(*t).data), n);
	n = T10_;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_3325)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n) {
	{
		NI T3_;
		NIM_BOOL T4_;
		T3_ = ((*t).data ? (*t).data->Sup.len : 0);
		T4_ = (NIM_BOOL)0;
		T4_ = mustRehash__astalgo_87(T3_, (*t).counter);
		if (!T4_) goto LA5_;
		strTableEnlarge__astalgo_3299(t);
	}
	LA5_: ;
	strTableRawInsert__astalgo_3245((&(*t).data), n);
	(*t).counter += ((NI) 1);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameValue__astalgo_119)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T6_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T7_;
			if (!((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15))) goto LA4_;
			T6_ = getInt__ast_4593(a);
			T7_ = getInt__ast_4593(b);
			result = eqeq___int495056_425(T6_, T7_);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18))) goto LA11_;
			result = ((*a)._kind_2.floatVal == (*b)._kind_2.floatVal);
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA16_;
			result = eqStrings((*a)._kind_3.strVal, (*b)._kind_3.strVal);
		}
		LA16_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIter__astalgo_3755)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	{
		while (1) {
			NI T3_;
			T3_ = ((tab.data ? tab.data->Sup.len : 0)-1);
			if (!((*ti).h <= T3_)) goto LA2;
			result = tab.data->data[(*ti).h];
			(*ti).h += ((NI) 1);
			{
				if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA6_;
				goto LA1;
			}
			LA6_: ;
		} LA2: ;
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initTabIter__astalgo_3770)(tyObject_TTabIter__Yn9cS7qgykm4tN4tshIyjSw* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	(*ti).h = ((NI) 0);
	{
		if (!(tab.counter == ((NI) 0))) goto LA3_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nextIter__astalgo_3755(ti, tab);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getModule__astalgo_216)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	result = s;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = !(((*result).kind == ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 6)));
			LA4_: ;
			if (!T3_) goto LA2;
			result = (*result).owner;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, idTableRawGet__astalgo_3806)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ t, NI key) {
	NI result;
	NI h;
	NI T1_;
{	result = (NI)0;
	h = (NI)0;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)(key & T1_);
	{
		while (1) {
			NI T8_;
			if (!!((t.data->data[h].key == ((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA*) NIM_NIL)))) goto LA3;
			{
				tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym174_;
				xX60gensym174_ = t.data->data[h].key;
				if (!((NI)((NI)((NU64)(((NI) ((*xX60gensym174_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym174_).itemId.item))) == key)) goto LA6_;
				result = h;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T8_);
		} LA3: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, idTableRawInsert__astalgo_3898)(tySequence__ZQPym9bf1jM5qaSn7LUXMKA** data, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, RootObj* val) {
	NI h;
	tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym182_;
	NI T1_;
	h = (NI)0;
	xX60gensym182_ = key;
	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((NI)((NI)((NU64)(((NI) ((*xX60gensym182_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym182_).itemId.item))) & T1_);
	{
		while (1) {
			NI T4_;
			if (!!(((*data)->data[h].key == ((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA*) NIM_NIL)))) goto LA3;
			T4_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T4_);
		} LA3: ;
	}
	asgnRef((void**) (&(*data)->data[h].key), key);
	asgnRef((void**) (&(*data)->data[h].val), val);
}
N_LIB_PRIVATE N_NIMCALL(void, idTablePut__astalgo_70)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ* t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, RootObj* val) {
	NI index;
	tySequence__ZQPym9bf1jM5qaSn7LUXMKA* n;
	tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym191_;
	index = (NI)0;
	n = NIM_NIL;
	xX60gensym191_ = key;
	index = idTableRawGet__astalgo_3806((*t), (NI)((NI)((NU64)(((NI) ((*xX60gensym191_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym191_).itemId.item))));
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		asgnRef((void**) (&(*t).data->data[index].val), val);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI T8_;
			NIM_BOOL T9_;
			NI T12_;
			tySequence__ZQPym9bf1jM5qaSn7LUXMKA* T21_;
			T8_ = ((*t).data ? (*t).data->Sup.len : 0);
			T9_ = (NIM_BOOL)0;
			T9_ = mustRehash__astalgo_87(T8_, (*t).counter);
			if (!T9_) goto LA10_;
			T12_ = ((*t).data ? (*t).data->Sup.len : 0);
			n = (tySequence__ZQPym9bf1jM5qaSn7LUXMKA*) newSeq((&NTItidpairseq__ZQPym9bf1jM5qaSn7LUXMKA_), ((NI) ((NI)(T12_ * ((NI) 2)))));
			{
				NI i;
				NI colontmp_;
				NI T14_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T14_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
				colontmp_ = T14_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp_)) goto LA16;
						i = res;
						{
							if (!!(((*t).data->data[i].key == ((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA*) NIM_NIL)))) goto LA19_;
							idTableRawInsert__astalgo_3898((&n), (*t).data->data[i].key, (*t).data->data[i].val);
						}
						LA19_: ;
						res += ((NI) 1);
					} LA16: ;
				}
			}
			T21_ = NIM_NIL;
			T21_ = (*t).data;
			unsureAsgnRef((void**) (&(*t).data), n);
			n = T21_;
		}
		LA10_: ;
		idTableRawInsert__astalgo_3898((&(*t).data), key, val);
		(*t).counter += ((NI) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__astalgo_64)(tyObject_TIdTable__Cs7vbulfMjKciTA2Uv9b6vQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key) {
	RootObj* result;
	NI index;
	tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym177_;
	result = NIM_NIL;
	xX60gensym177_ = key;
	index = idTableRawGet__astalgo_3806(t, (NI)((NI)((NU64)(((NI) ((*xX60gensym177_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym177_).itemId.item))));
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		result = t.data->data[index].val;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((RootObj*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentIter__astalgo_3401)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI h;
	NI T1_;
	NI start;
	NI T13_;
	result = NIM_NIL;
	T1_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	h = (NI)((*ti).h & T1_);
	start = h;
	result = tab.data->data[h];
	{
		while (1) {
			NI T8_;
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3;
			{
				if (!((*(*result).name).id == (*(*ti).name).id)) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			T8_ = ((tab.data ? tab.data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T8_);
			{
				if (!(h == start)) goto LA11_;
				result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				goto LA2;
			}
			LA11_: ;
			result = tab.data->data[h];
		} LA3: ;
	} LA2: ;
	T13_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	(*ti).h = nextTry__astalgo_90(h, T13_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, initIdentIter__astalgo_3420)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	(*ti).h = (*s).h;
	unsureAsgnRef((void**) (&(*ti).name), s);
	{
		if (!(tab.counter == ((NI) 0))) goto LA3_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nextIdentIter__astalgo_3401(ti, tab);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, strTableInclReportConflict__astalgo_3335)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n, NIM_BOOL onConflictKeepOld) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI h;
	NI T1_;
	NI replaceSlot;
{	result = NIM_NIL;
	T1_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
	h = (NI)((*(*n).name).h & T1_);
	replaceSlot = ((NI) -1);
	{
		while (1) {
			tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
			NI T16_;
			it = (*t).data->data[h];
			{
				if (!(it == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL))) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			{
				if (!((*(*it).name).id == (*(*n).name).id)) goto LA10_;
				{
					if (!(it == n)) goto LA14_;
					result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA14_: ;
				replaceSlot = h;
			}
			LA10_: ;
			T16_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T16_);
		}
	} LA2: ;
	{
		if (!(((NI) 0) <= replaceSlot)) goto LA19_;
		result = (*t).data->data[replaceSlot];
		{
			if (!!(onConflictKeepOld)) goto LA23_;
			asgnRef((void**) (&(*t).data->data[replaceSlot]), n);
		}
		LA23_: ;
		goto BeforeRet_;
	}
	goto LA17_;
	LA19_: ;
	{
		NI T26_;
		NIM_BOOL T27_;
		T26_ = ((*t).data ? (*t).data->Sup.len : 0);
		T27_ = (NIM_BOOL)0;
		T27_ = mustRehash__astalgo_87(T26_, (*t).counter);
		if (!T27_) goto LA28_;
		strTableEnlarge__astalgo_3299(t);
		strTableRawInsert__astalgo_3245((&(*t).data), n);
	}
	goto LA17_;
	LA28_: ;
	{
		asgnRef((void**) (&(*t).data->data[h]), n);
	}
	LA17_: ;
	(*t).counter += ((NI) 1);
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameIgnoreBacktickGensymInfo__astalgo_264)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI i;
	NI j;
{	result = (NIM_BOOL)0;
	{
		if (!!(((NU8)(a->data[((NI) 0)]) == (NU8)(b->data[((NI) 0)])))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	alen = (NI)((a ? a->Sup.len : 0) - ((NI) 1));
	{
		while (1) {
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((NI) 0) < alen);
			if (!(T7_)) goto LA8_;
			T7_ = !(((NU8)(a->data[alen]) == (NU8)(96)));
			LA8_: ;
			if (!T7_) goto LA6;
			alen -= ((NI) 1);
		} LA6: ;
	}
	{
		if (!(alen <= ((NI) 0))) goto LA11_;
		alen = (a ? a->Sup.len : 0);
	}
	LA11_: ;
	i = ((NI) 1);
	j = ((NI) 1);
	{
		while (1) {
			NIM_CHAR aa;
			NIM_CHAR bb;
			{
				while (1) {
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = (i < alen);
					if (!(T17_)) goto LA18_;
					T17_ = ((NU8)(a->data[i]) == (NU8)(95));
					LA18_: ;
					if (!T17_) goto LA16;
					i += ((NI) 1);
				} LA16: ;
			}
			{
				while (1) {
					NIM_BOOL T21_;
					T21_ = (NIM_BOOL)0;
					T21_ = (j < (b ? b->Sup.len : 0));
					if (!(T21_)) goto LA22_;
					T21_ = ((NU8)(b->data[j]) == (NU8)(95));
					LA22_: ;
					if (!T21_) goto LA20;
					j += ((NI) 1);
				} LA20: ;
			}
			{
				if (!(i < alen)) goto LA25_;
				aa = nsuToLowerAsciiChar(a->data[i]);
			}
			goto LA23_;
			LA25_: ;
			{
				aa = 0;
			}
			LA23_: ;
			{
				if (!(j < (b ? b->Sup.len : 0))) goto LA30_;
				bb = nsuToLowerAsciiChar(b->data[j]);
			}
			goto LA28_;
			LA30_: ;
			{
				bb = 0;
			}
			LA28_: ;
			{
				if (!!(((NU8)(aa) == (NU8)(bb)))) goto LA35_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			LA35_: ;
			{
				if (!(alen <= i)) goto LA39_;
				{
					if (!((b ? b->Sup.len : 0) <= j)) goto LA43_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA43_: ;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			goto LA37_;
			LA39_: ;
			{
				if (!((b ? b->Sup.len : 0) <= j)) goto LA46_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			goto LA37_;
			LA46_: ;
			LA37_: ;
			i += ((NI) 1);
			j += ((NI) 1);
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getNamedParamFromList__astalgo_293)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* list, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(list);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*(*list)._kind_6.sons->data[i])._kind_4.sym;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*(*it).name).id == (*ident).id);
					if (T6_) goto LA7_;
					T6_ = sameIgnoreBacktickGensymInfo__astalgo_264((*(*it).name).s, (*ident).s);
					LA7_: ;
					if (!T6_) goto LA8_;
					result = it;
					goto BeforeRet_;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, nextIdentExcluding__astalgo_3425)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* excluding) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	NI h;
	NI T1_;
	NI start;
	NI T16_;
	result = NIM_NIL;
	T1_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	h = (NI)((*ti).h & T1_);
	start = h;
	result = tab.data->data[h];
	{
		while (1) {
			NI T11_;
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3;
			{
				NIM_BOOL T6_;
				tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym168_;
				NIM_BOOL T8_;
				T6_ = (NIM_BOOL)0;
				T6_ = ((*(*result).name).id == (*(*ti).name).id);
				if (!(T6_)) goto LA7_;
				xX60gensym168_ = result;
				T8_ = (NIM_BOOL)0;
				T8_ = contains__astalgo_3489(excluding, (NI)((NI)((NU64)(((NI) ((*xX60gensym168_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym168_).Sup.itemId.item))));
				T6_ = !(T8_);
				LA7_: ;
				if (!T6_) goto LA9_;
				goto LA2;
			}
			LA9_: ;
			T11_ = ((tab.data ? tab.data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T11_);
			{
				if (!(h == start)) goto LA14_;
				result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
				goto LA2;
			}
			LA14_: ;
			result = tab.data->data[h];
		} LA3: ;
	} LA2: ;
	T16_ = ((tab.data ? tab.data->Sup.len : 0)-1);
	(*ti).h = nextTry__astalgo_90(h, T16_);
	{
		NIM_BOOL T19_;
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* xX60gensym170_;
		T19_ = (NIM_BOOL)0;
		T19_ = !((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
		if (!(T19_)) goto LA20_;
		xX60gensym170_ = result;
		T19_ = contains__astalgo_3489(excluding, (NI)((NI)((NU64)(((NI) ((*xX60gensym170_).Sup.itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym170_).Sup.itemId.item))));
		LA20_: ;
		if (!T19_) goto LA21_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	LA21_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, firstIdentExcluding__astalgo_3747)(tyObject_TIdentIter__Lp4Mt9aetG3F7zvSvi9cZw6g* ti, tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw tab, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* s, tyObject_PackedSet__THXDbzJSs2hcC9a33en2pdw* excluding) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
	result = NIM_NIL;
	(*ti).h = (*s).h;
	unsureAsgnRef((void**) (&(*ti).name), s);
	{
		if (!(tab.counter == ((NI) 0))) goto LA3_;
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = nextIdentExcluding__astalgo_3425(ti, tab, excluding);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, lookupInRecord__astalgo_84)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* field) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_3155(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = lookupInRecord__astalgo_84((*n)._kind_6.sons->data[i], field);
					{
						if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 139):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3)))) goto LA12_;
			result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA12_: ;
		result = lookupInRecord__astalgo_84((*n)._kind_6.sons->data[((NI) 0)], field);
		{
			if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA16_;
			goto BeforeRet_;
		}
		LA16_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_3155(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA20;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 85):
					case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 88):
					{
						tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* T22_;
						T22_ = NIM_NIL;
						T22_ = lastSon__ast_4833((*n)._kind_6.sons->data[i_3]);
						result = lookupInRecord__astalgo_84(T22_, field);
						{
							if (!!((result == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA25_;
							goto BeforeRet_;
						}
						LA25_: ;
					}
					break;
					default:
					{
						result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
						goto BeforeRet_;
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3):
	{
		{
			if (!((*(*(*n)._kind_4.sym).name).id == (*field).id)) goto LA31_;
			result = (*n)._kind_4.sym;
		}
		LA31_: ;
	}
	break;
	default:
	{
		result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, idNodeTableRawGet__astalgo_4017)(tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key) {
	NI result;
	NI h;
	tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym199_;
	NI T1_;
{	result = (NI)0;
	h = (NI)0;
	xX60gensym199_ = key;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((NI)((NI)((NU64)(((NI) ((*xX60gensym199_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym199_).itemId.item))) & T1_);
	{
		while (1) {
			NI T8_;
			if (!!((t.data->data[h].key == ((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA*) NIM_NIL)))) goto LA3;
			{
				tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym201_;
				tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym202_;
				xX60gensym201_ = t.data->data[h].key;
				xX60gensym202_ = key;
				if (!((NI)((NI)((NU64)(((NI) ((*xX60gensym201_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym201_).itemId.item))) == (NI)((NI)((NU64)(((NI) ((*xX60gensym202_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym202_).itemId.item))))) goto LA6_;
				result = h;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T8_);
		} LA3: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, idNodeTableGet__astalgo_77)(tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	NI index;
	result = NIM_NIL;
	index = (NI)0;
	index = idNodeTableRawGet__astalgo_4017(t, key);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		result = t.data->data[index].val;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, idNodeTableRawInsert__astalgo_4064)(tySequence__FWZlrpY7KaSkhECxQricPA** data, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val) {
	NI h;
	tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* xX60gensym204_;
	NI T1_;
	h = (NI)0;
	xX60gensym204_ = key;
	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((NI)((NI)((NU64)(((NI) ((*xX60gensym204_).itemId.module))) << (NU64)(((NI) 24))) + ((NI) ((*xX60gensym204_).itemId.item))) & T1_);
	{
		while (1) {
			NI T4_;
			if (!!(((*data)->data[h].key == ((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA*) NIM_NIL)))) goto LA3;
			T4_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T4_);
		} LA3: ;
	}
	asgnRef((void**) (&(*data)->data[h].key), key);
	asgnRef((void**) (&(*data)->data[h].val), val);
}
N_LIB_PRIVATE N_NIMCALL(void, idNodeTablePut__astalgo_80)(tyObject_TIdNodeTable__zHo8r5mhXnHKLuROOvz0GQ* t, tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA* key, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* val) {
	NI index;
	index = idNodeTableRawGet__astalgo_4017((*t), key);
	{
		if (!(((NI) 0) <= index)) goto LA3_;
		asgnRef((void**) (&(*t).data->data[index].val), val);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI T8_;
			NIM_BOOL T9_;
			tySequence__FWZlrpY7KaSkhECxQricPA* n;
			NI T12_;
			tySequence__FWZlrpY7KaSkhECxQricPA* T21_;
			T8_ = ((*t).data ? (*t).data->Sup.len : 0);
			T9_ = (NIM_BOOL)0;
			T9_ = mustRehash__astalgo_87(T8_, (*t).counter);
			if (!T9_) goto LA10_;
			n = NIM_NIL;
			T12_ = ((*t).data ? (*t).data->Sup.len : 0);
			n = (tySequence__FWZlrpY7KaSkhECxQricPA*) newSeq((&NTItidnodepairseq__FWZlrpY7KaSkhECxQricPA_), ((NI) ((NI)(T12_ * ((NI) 2)))));
			{
				NI i;
				NI colontmp_;
				NI T14_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T14_ = (((*t).data ? (*t).data->Sup.len : 0)-1);
				colontmp_ = T14_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp_)) goto LA16;
						i = res;
						{
							if (!!(((*t).data->data[i].key == ((tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA*) NIM_NIL)))) goto LA19_;
							idNodeTableRawInsert__astalgo_4064((&n), (*t).data->data[i].key, (*t).data->data[i].val);
						}
						LA19_: ;
						res += ((NI) 1);
					} LA16: ;
				}
			}
			T21_ = NIM_NIL;
			T21_ = (*t).data;
			unsureAsgnRef((void**) (&(*t).data), n);
			n = T21_;
		}
		LA10_: ;
		idNodeTableRawInsert__astalgo_4064((&(*t).data), key, val);
		(*t).counter += ((NI) 1);
	}
	LA1_: ;
}
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b) {
	NI result;
	NI alen;
	NI blen;
	NI minlen;
	result = (NI)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	minlen = ((alen <= blen) ? alen : blen);
	{
		int T5_;
		if (!(((NI) 0) < minlen)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((size_t) (minlen)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI) 0))) goto LA8_;
			result = (NI)(alen - blen);
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (NI)(alen - blen);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValue__astalgo_135)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15):
	{
		{
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T6_;
			tyObject_Int128__ZSLNyYMaD8rorY4HZRFSUQ T7_;
			if (!((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 15))) goto LA4_;
			T6_ = getInt__ast_4593(a);
			T7_ = getInt__ast_4593(b);
			result = lteq___int495056_421(T6_, T7_);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 16) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 18))) goto LA11_;
			result = ((*a)._kind_2.floatVal <= (*b)._kind_2.floatVal);
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22):
	{
		{
			if (!((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 20) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22))) goto LA16_;
			result = (cmpStrings((*a)._kind_3.strVal, (*b)._kind_3.strVal) <= 0);
		}
		LA16_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg, weakLeValue__astalgo_151)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* a, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* b) {
	tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg result;
	result = (tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*a).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*a).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22)));
		if (T3_) goto LA4_;
		T3_ = !(((*b).kind >= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 5) && (*b).kind <= ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 22)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 0);
	}
	goto LA1_;
	LA5_: ;
	{
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = leValue__astalgo_135(a, b);
			if (!T10_) goto LA11_;
			result = ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 2);
		}
		goto LA8_;
		LA11_: ;
		{
			result = ((tyEnum_TImplication__IpKb3A5pjRWQdH9cJ0v9cKgg) 1);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*, getSymFromList__astalgo_245)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* list, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident, NI start) {
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* result;
{	result = NIM_NIL;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_3155(list);
		i_2 = start;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!((*(*list)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3))) goto LA6_;
					result = (*(*list)._kind_6.sons->data[i])._kind_4.sym;
					{
						if (!((*(*result).name).id == (*ident).id)) goto LA10_;
						goto BeforeRet_;
					}
					LA10_: ;
				}
				goto LA4_;
				LA6_: ;
				{
					result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableIncl__astalgo_3374)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n, NIM_BOOL onConflictKeepOld) {
	NIM_BOOL result;
	tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* T1_;
	result = (NIM_BOOL)0;
	T1_ = NIM_NIL;
	T1_ = strTableInclReportConflict__astalgo_3335(t, n, onConflictKeepOld);
	result = !((T1_ == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, skipConvCastAndClosure__astalgo_114)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	result = NIM_NIL;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 67):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 66):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 70):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 68):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 69):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 155):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 58):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 59):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 60):
			case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 61):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAddrNode__astalgo_4290)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 63):
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 64):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) ... ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 3));
			if (!(T5_)) goto LA6_;
			T5_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag) 16));
			LA6_: ;
			if (!T5_) goto LA7_;
			result = NIM_TRUE;
		}
		goto LA3_;
		LA7_: ;
		{
			result = NIM_FALSE;
		}
		LA3_: ;
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, listSymbolNames__astalgo_4303)(tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** symbols, NI symbolsLen_0) {
	NimStringDesc* result;
	result = NIM_NIL;
	{
		tyObject_TSym__3r34mwqcVmg5JFNmiaVncw** sym;
		NI i;
		sym = (tyObject_TSym__3r34mwqcVmg5JFNmiaVncw**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < symbolsLen_0)) goto LA3;
				sym = &symbols[i];
				{
					if (!(((NI) 0) < (result ? result->Sup.len : 0))) goto LA6_;
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__9cMUSicDjYZo0cQYwMNqa9cA_22));
				}
				LA6_: ;
				result = resizeString(result, ((*(*(*sym)).name).s ? (*(*(*sym)).name).s->Sup.len : 0) + 0);
appendString(result, (*(*(*sym)).name).s);
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symTabReplaceRaw__astalgo_3270)(tySequence__ed0C0uAUZPhvw3RAc5hfYg** data, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prevSym, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* newSym) {
	NI h;
	NI T1_;
{	T1_ = (((*data) ? (*data)->Sup.len : 0)-1);
	h = (NI)((*(*prevSym).name).h & T1_);
	{
		while (1) {
			NI T8_;
			if (!!(((*data)->data[h] == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3;
			{
				if (!((*data)->data[h] == prevSym)) goto LA6_;
				asgnRef((void**) (&(*data)->data[h]), newSym);
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = (((*data) ? (*data)->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T8_);
		} LA3: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, symTabReplace__astalgo_3295)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw* t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* prevSym, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* newSym) {
	symTabReplaceRaw__astalgo_3270((&(*t).data), prevSym, newSym);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscriminantField__astalgo_4328)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 46))) goto LA3_;
		result = (((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 20))&63U)))!=0);
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 45))) goto LA6_;
		result = (((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA) 20))&63U)))!=0);
	}
	goto LA1_;
	LA6_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableContains__astalgo_3226)(tyObject_TStrTable__CJQ42V2zij8fd39a9aMiwtZw t, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* n) {
	NIM_BOOL result;
	NI h;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*(*n).name).h & T1_);
	{
		while (1) {
			NI T8_;
			if (!!((t.data->data[h] == ((tyObject_TSym__3r34mwqcVmg5JFNmiaVncw*) NIM_NIL)))) goto LA3;
			{
				if (!(t.data->data[h] == n)) goto LA6_;
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			LA6_: ;
			T8_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__astalgo_90(h, T8_);
		} LA3: ;
	}
	result = NIM_FALSE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmastalgodotnim_DatInit000)(void) {
static TNimNode* TM__9cMUSicDjYZo0cQYwMNqa9cA_2_3[3];
static TNimNode TM__9cMUSicDjYZo0cQYwMNqa9cA_0[4];
NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_.size = sizeof(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g);
NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_.align = NIM_ALIGNOF(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g);
NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_.kind = 18;
NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_.base = 0;
NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_.flags = 3;
TM__9cMUSicDjYZo0cQYwMNqa9cA_2_3[0] = &TM__9cMUSicDjYZo0cQYwMNqa9cA_0[1];
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[1].kind = 1;
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[1].offset = offsetof(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g, Field0);
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[1].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[1].name = "Field0";
TM__9cMUSicDjYZo0cQYwMNqa9cA_2_3[1] = &TM__9cMUSicDjYZo0cQYwMNqa9cA_0[2];
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[2].kind = 1;
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[2].offset = offsetof(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g, Field1);
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[2].typ = (&NTIpointer__vr5DoT1jILTGdRlYv1OYpw_);
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[2].name = "Field1";
TM__9cMUSicDjYZo0cQYwMNqa9cA_2_3[2] = &TM__9cMUSicDjYZo0cQYwMNqa9cA_0[3];
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[3].kind = 1;
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[3].offset = offsetof(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g, Field2);
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[3].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[3].name = "Field2";
TM__9cMUSicDjYZo0cQYwMNqa9cA_0[0].len = 3; TM__9cMUSicDjYZo0cQYwMNqa9cA_0[0].kind = 2; TM__9cMUSicDjYZo0cQYwMNqa9cA_0[0].sons = &TM__9cMUSicDjYZo0cQYwMNqa9cA_2_3[0];
NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_.node = &TM__9cMUSicDjYZo0cQYwMNqa9cA_0[0];
NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_.size = sizeof(tySequence__9chP3SzkaldXzawWQCDsqqg*);
NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_.align = NIM_ALIGNOF(tySequence__9chP3SzkaldXzawWQCDsqqg*);
NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_.kind = 24;
NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_.base = (&NTIkeyvaluepair__aGv2fk9ceddvdC01ZJC2Q2g_);
NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_.flags = 2;
NTIkeyvaluepairseq__9chP3SzkaldXzawWQCDsqqg_.marker = Marker_tySequence__9chP3SzkaldXzawWQCDsqqg;
}

